@@ -1,3 +1,4 @@
+from django.db.models import Count
 from django_readers import projectors, qs
 
 
@@ -42,6 +43,24 @@ def field_display(name):
     )
 
 
+def count(name, distinct=True):
+    attr_name = f"{name}_count"
+    return (
+        qs.annotate(**{attr_name: Count(name, distinct=distinct)}),
+        projectors.attr(attr_name),
+    )
+
+
+def has(name, distinct=True):
+    attr_name = f"{name}_count"
+    return (
+        qs.annotate(**{attr_name: Count(name, distinct=distinct)}),
+        projectors.alias(
+            f"has_{name}", projectors.attr(attr_name, transform_value=bool)
+        ),
+    )
+
+
 def filter(*args, **kwargs):
     return prepare_only(qs.filter(*args, **kwargs))
 
